==> path_stack-0.0.2.tar.gz: example/lib/advanced_tab_example_pages.dart <==
import 'package:example/main.dart';
import 'package:flutter/material.dart';
import 'package:path_stack/path_stack.dart';

import 'advanced_tab_example.dart';

class MainScaffold extends StatefulWidget {
  final Widget child;

  const MainScaffold({Key? key, required this.child}) : super(key: key);

  @override
  _MainScaffoldState createState() => _MainScaffoldState();
}

class _MainScaffoldState extends State<MainScaffold> {
  int buildCount = 0;
  @override
  Widget build(BuildContext context) {
    print(MediaQuery.of(context).size.width);
    TextStyle textStyle = TextStyle(fontSize: 32);
    TextStyle getStyle(String path) =>
        pathNotifier.value.contains(path) ? textStyle.copyWith(color: Colors.black) : textStyle;
    return Stack(
      children: [
        BackBtn(),
        Padding(
          padding: const EdgeInsets.all(8.0).copyWith(top: 40),
          child: Column(
            children: [
              // pretend url bar
              Container(
                padding: EdgeInsets.all(12),
                color: Colors.grey.shade200,
                width: double.infinity,
                child: Text("https://myflutterapp/${pathNotifier.value}",
                    style: TextStyle(fontSize: 16, fontWeight: FontWeight.w600)),
              ),
              Expanded(child: widget.child),
              Row(children: [
                _UrlBtn("home", url: AppPaths.tabsCategory + HomePage.path),
                _UrlBtn("settings",
                    url: AppPaths.tabsCategory + SettingsHome.path + ProfileSettings.path,
                    alias: AppPaths.tabsCategory + SettingsHome.path),
              ]),
            ],
          ),
        ),
        Positioned(
          bottom: 80,
          right: 12,
          child: FloatingActionButton(onPressed: () => pathNotifier.value = ComposePage.path, child: Icon(Icons.add)),
        )
      ],
    );
  }
}

class SettingsScaffold extends StatefulWidget {
  final Widget child;

  const SettingsScaffold({Key? key, required this.child}) : super(key: key);

  @override
  _SettingsScaffoldState createState() => _SettingsScaffoldState();
}

class _SettingsScaffoldState extends State<SettingsScaffold> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Column(children: [
        Row(
          children: [
            _UrlBtn("profile", url: "${AppPaths.tabsCategory}${SettingsHome.path}${ProfileSettings.path}"),
            _UrlBtn("alerts", url: "${AppPaths.tabsCategory}${SettingsHome.path}${AlertSettings.path}"),
            _UrlBtn("Billing", url: "${AppPaths.tabsCategory}${SettingsHome.path}${BillingSettings.path}"),
          ],
        ),
        Expanded(child: widget.child),
      ]),
    );
  }
}

class _UrlBtn extends StatelessWidget {
  final String url;
  final String? alias;
  final String label;

  const _UrlBtn(this.label, {Key? key, required this.url, this.alias}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    bool isSelected = pathNotifier.value.contains(alias ?? url);
    TextStyle textStyle = TextStyle(fontSize: 22, color: isSelected ? Colors.black : Colors.blue);
    return Expanded(
      child: OutlinedButton(
          onPressed: () {
            pathNotifier.value = url;
          },
          child: Padding(padding: EdgeInsets.symmetric(vertical: 10), child: Text(label, style: textStyle))),
    );
  }
}

class SomeStatefulPage extends StatefulWidget {
  SomeStatefulPage(String title, {Key? key}) : super(key: key) {
    this.title = title;
    print("${this} TITLE = $title");
  }
  late final String title;

  @override
  _SomeStatefulPageState createState() => _SomeStatefulPageState();
}

class _SomeStatefulPageState extends State<SomeStatefulPage> {
  List<int>? items;
  TextEditingController txtController = TextEditingController();
  @override
  void initState() {
    super.initState();
    Future.delayed(Duration(seconds: 1), () {
      if (mounted == false) return;
      setState(() => items = List.generate(100, (index) => index));
    });
  }

  @override
  Widget build(BuildContext context) {
    if (items == null) return Center(child: CircularProgressIndicator());
    return Column(
      children: [
        Row(
          children: [
            Text(widget.title, style: TextStyle(fontSize: 22)),
            Spacer(),
            Text("Search Filter:", style: TextStyle(fontSize: 16)),
            Expanded(
                child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: TextFormField(
                decoration: InputDecoration(border: OutlineInputBorder()),
              ),
            )),
          ],
        ),
        Expanded(
            child: ListView.builder(
                itemBuilder: (_, index) => TextButton(
                      onPressed: () => pathNotifier.value = "${DetailsPage.path}$index",
                      child: Container(
                        width: double.infinity,
                        padding: const EdgeInsets.all(8.0),
                        color: (index % 2 == 0 ? Colors.grey : Colors.white).withOpacity(.1),
                        child: Text("ITEM: $index"),
                      ),
                    ))),
      ],
    );
  }
}

class HomePage extends SomeStatefulPage {
  static const String path = "home";
  HomePage(String suffix) : super("Home Page, $suffix");
}

class SettingsHome extends SomeStatefulPage {
  static const String path = "settings/";
  SettingsHome(String suffix) : super("Settings Home, $suffix");
}

class ProfileSettings extends SomeStatefulPage {
  static const String path = "profile";
  ProfileSettings(String suffix) : super("Profile Settings, $suffix");
}

class AlertSettings extends SomeStatefulPage {
  static const String path = "alerts";
  AlertSettings(String suffix) : super("Alert Settings, $suffix");
}

class BillingSettings extends SomeStatefulPage {
  static const String path = "billing";
  BillingSettings(String suffix) : super("Billing Settings, $suffix");
}

class ComposePage extends StatefulWidget {
  static const String path = "compose";
  @override
  _ComposePageState createState() => _ComposePageState();
}

class _ComposePageState extends State<ComposePage> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          BackBtn(),
          Text("New Message:", style: TextStyle(fontSize: 32)),
          TextField(
              maxLines: 10,
              decoration: InputDecoration(border: OutlineInputBorder(borderSide: BorderSide(color: Colors.black)))),
          OutlinedButton(
              onPressed: goBack,
              child: Padding(
                padding: const EdgeInsets.symmetric(horizontal: 100, vertical: 10),
                child: Text("SUBMIT"),
              ))
        ],
      ),
    );
  }
}

class DetailsPage extends StatefulWidget {
  static const String path = "details/";

  DetailsPage({required this.itemId}) : super();
  final String? itemId;
  @override
  _DetailsPageState createState() => _DetailsPageState();
}

class _DetailsPageState extends State<DetailsPage> {
  // Simulates a list of items loaded from the database.
  // Normally this would be driven by some API call or model that exists above this view.
  // The point of this is to just show how we can create a history-stack from a fullscreen view.
  List<String> items = List.generate(100, (index) => "$index");
  @override
  Widget build(BuildContext context) {
    print(history.toString());
    return Padding(
      padding: const EdgeInsets.all(20),
      child: Column(
        children: [
          Row(children: [BackBtn(), Spacer(), CloseButton(onPressed: () => popMatching(DetailsPage.path))]),
          Text("${widget.itemId}", style: TextStyle(fontSize: 32)),
          Row(
            children: [
              TextButton(
                  onPressed: () => pathNotifier.value = "${DetailsPage.path}${getId(-1)}", child: Text("<< prev item")),
              Spacer(),
              TextButton(
                  onPressed: () => pathNotifier.value = "${DetailsPage.path}${getId(1)}", child: Text("next item >>")),
            ],
          ),
        ],
      ),
    );
  }

  String getId(int dir) {
    int currentIndex = items.indexOf(widget.itemId!);
    currentIndex += dir;
    if (currentIndex <= 0) {
      currentIndex = items.length - 1;
    } else if (currentIndex > items.length - 1) {
      currentIndex = 0;
    }
    return items[currentIndex];
  }
}

==> path_stack-0.2.0.tar.gz: example/lib/advanced_tab_example_pages.dart <==
import 'package:flutter/material.dart';

import 'advanced_tab_example.dart';

class MainScaffold extends StatefulWidget {
  final Widget child;

  const MainScaffold({Key? key, required this.child}) : super(key: key);

  @override
  _MainScaffoldState createState() => _MainScaffoldState();
}

class _MainScaffoldState extends State<MainScaffold> {
  int buildCount = 0;
  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Padding(
          padding: const EdgeInsets.all(8.0).copyWith(top: 40),
          child: Column(
            children: [
              // pretend url bar
              Container(
                padding: EdgeInsets.all(12),
                color: Colors.grey.shade200,
                width: double.infinity,
                child: Text("https://myflutterapp/${pathNotifier.value}",
                    style: TextStyle(fontSize: 16, fontWeight: FontWeight.w600)),
              ),
              Expanded(child: widget.child),
              Row(children: [
                _UrlBtn("home", url: AppPaths.tabsCategory + HomePage.path),
                _UrlBtn("settings",
                    url: AppPaths.tabsCategory + SettingsHome.path + ProfileSettings.path,
                    alias: AppPaths.tabsCategory + SettingsHome.path),
              ]),
            ],
          ),
        ),
      ],
    );
  }
}

class SettingsScaffold extends StatefulWidget {
  final Widget child;

  const SettingsScaffold({Key? key, required this.child}) : super(key: key);

  @override
  _SettingsScaffoldState createState() => _SettingsScaffoldState();
}

class _SettingsScaffoldState extends State<SettingsScaffold> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Column(children: [
        Row(
          children: [
            _UrlBtn("profile", url: "${AppPaths.tabsCategory}${SettingsHome.path}${ProfileSettings.path}"),
            _UrlBtn("alerts", url: "${AppPaths.tabsCategory}${SettingsHome.path}${AlertSettings.path}"),
            _UrlBtn("Billing", url: "${AppPaths.tabsCategory}${SettingsHome.path}${BillingSettings.path}"),
          ],
        ),
        Expanded(child: widget.child),
      ]),
    );
  }
}

class _UrlBtn extends StatelessWidget {
  final String url;
  final String? alias;
  final String label;

  const _UrlBtn(this.label, {Key? key, required this.url, this.alias}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    bool isSelected = pathNotifier.value.contains(alias ?? url);
    TextStyle textStyle = TextStyle(fontSize: 22, color: isSelected ? Colors.black : Colors.blue);
    return Expanded(
      child: OutlinedButton(
          onPressed: () {
            pathNotifier.value = url;
          },
          child: Padding(padding: EdgeInsets.symmetric(vertical: 10), child: Text(label, style: textStyle))),
    );
  }
}

class SomeStatefulPage extends StatefulWidget {
  SomeStatefulPage(String title, {Key? key}) : super(key: key) {
    this.title = title;
    print("${this} TITLE = $title");
  }
  late final String title;

  @override
  _SomeStatefulPageState createState() => _SomeStatefulPageState();
}

class _SomeStatefulPageState extends State<SomeStatefulPage> {
  List<int>? items;
  TextEditingController txtController = TextEditingController();
  @override
  void initState() {
    super.initState();
    Future.delayed(Duration(seconds: 1), () {
      if (mounted == false) return;
      setState(() => items = List.generate(100, (index) => index));
    });
  }

  @override
  Widget build(BuildContext context) {
    if (items == null) return Center(child: CircularProgressIndicator());
    return Column(
      children: [
        Row(
          children: [
            Text(widget.title, style: TextStyle(fontSize: 22)),
            Spacer(),
            Text("Search Filter:", style: TextStyle(fontSize: 16)),
            Expanded(
                child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: TextFormField(
                decoration: InputDecoration(border: OutlineInputBorder()),
              ),
            )),
          ],
        ),
        Expanded(
            child: ListView.builder(
                itemBuilder: (_, index) => Container(
                      width: double.infinity,
                      padding: const EdgeInsets.all(8.0),
                      color: (index % 2 == 0 ? Colors.grey : Colors.white).withOpacity(.1),
                      child: Text("ITEM: $index"),
                    ))),
      ],
    );
  }
}

class HomePage extends SomeStatefulPage {
  static const String path = "home";
  HomePage(String suffix) : super("Home Page, $suffix");
}

class SettingsHome extends SomeStatefulPage {
  static const String path = "settings/";
  SettingsHome(String suffix) : super("Settings Home, $suffix");
}

class ProfileSettings extends SomeStatefulPage {
  static const String path = "profile";
  ProfileSettings(String suffix) : super("Profile Settings, $suffix");
}

class AlertSettings extends SomeStatefulPage {
  static const String path = "alerts";
  AlertSettings(String suffix) : super("Alert Settings, $suffix");
}

class BillingSettings extends SomeStatefulPage {
  static const String path = "billing";
  BillingSettings(String suffix) : super("Billing Settings, $suffix");
}
